Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(185)

Unified Diff: components/arc/test/fake_arc_session.h

Issue 2425753002: Rename ArcBridgeBootstrap to ArcSession. (Closed)
Patch Set: Address comment. Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « components/arc/test/fake_arc_bridge_bootstrap.cc ('k') | components/arc/test/fake_arc_session.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: components/arc/test/fake_arc_session.h
diff --git a/components/arc/test/fake_arc_bridge_bootstrap.h b/components/arc/test/fake_arc_session.h
similarity index 60%
rename from components/arc/test/fake_arc_bridge_bootstrap.h
rename to components/arc/test/fake_arc_session.h
index 2e3253dcaf56b837c541504429c951acf0398966..a8f6ed04897a585e18ffd60982bc7916fa4c128f 100644
--- a/components/arc/test/fake_arc_bridge_bootstrap.h
+++ b/components/arc/test/fake_arc_session.h
@@ -2,23 +2,23 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef COMPONENTS_ARC_TEST_FAKE_ARC_BRIDGE_BOOTSTRAP_H_
-#define COMPONENTS_ARC_TEST_FAKE_ARC_BRIDGE_BOOTSTRAP_H_
+#ifndef COMPONENTS_ARC_TEST_FAKE_ARC_SESSION_H_
+#define COMPONENTS_ARC_TEST_FAKE_ARC_SESSION_H_
#include <memory>
#include "base/macros.h"
-#include "components/arc/arc_bridge_bootstrap.h"
+#include "components/arc/arc_session.h"
namespace arc {
-// A fake ArcBridgeBootstrap that creates a local connection.
-class FakeArcBridgeBootstrap : public ArcBridgeBootstrap {
+// A fake ArcSession that creates a local connection.
+class FakeArcSession : public ArcSession {
public:
- FakeArcBridgeBootstrap();
- ~FakeArcBridgeBootstrap() override;
+ FakeArcSession();
+ ~FakeArcSession() override;
- // ArcBridgeBootstrap:
+ // ArcSession overrides:
void Start() override;
void Stop() override;
@@ -34,9 +34,9 @@ class FakeArcBridgeBootstrap : public ArcBridgeBootstrap {
// Emulate Start() is suspended at some phase, before OnReady() is invoked.
void SuspendBoot();
// Returns FakeArcBridgeBootstrap instance. This can be used for a factory
// in ArcBridgeServiceImpl.
- static std::unique_ptr<ArcBridgeBootstrap> Create();
+ static std::unique_ptr<ArcSession> Create();
private:
bool boot_failure_emulation_enabled_ = false;
@@ -44,9 +44,9 @@ class FakeArcBridgeBootstrap : public ArcBridgeBootstrap {
bool boot_suspended_ = false;
- DISALLOW_COPY_AND_ASSIGN(FakeArcBridgeBootstrap);
+ DISALLOW_COPY_AND_ASSIGN(FakeArcSession);
};
} // namespace arc
-#endif // COMPONENTS_ARC_TEST_FAKE_ARC_BRIDGE_BOOTSTRAP_H_
+#endif // COMPONENTS_ARC_TEST_FAKE_ARC_SESSION_H_
« no previous file with comments | « components/arc/test/fake_arc_bridge_bootstrap.cc ('k') | components/arc/test/fake_arc_session.cc » ('j') | no next file with comments »

Powered by Google App Engine
@@ -34,9 +34,9 @@ class FakeArcBridgeBootstrap : public ArcBridgeBootstrap {
// Emulate Start() is suspended at some phase, before OnReady() is invoked.
void SuspendBoot();
- // Returns FakeArcBridgeBootstrap instance. This can be used for a factory
+ // Returns FakeArcSession instance. This can be used for a factory
// in ArcBridgeServiceImpl.
This is Rietveld 408576698